Recipe

Struct Recipe 

pub struct Recipe {
    pub name: Option<String>,
    pub author: Option<String>,
    pub description: Option<String>,
    pub ingredients: Vec<Ingredient>,
    pub how_to_sections: Vec<HowToSection>,
}
A recipe extracted from HTML using parse_recipe.

Fields

name: Option<String>

The name of the recipe.

author: Option<String>

The author of the recipe.

If the recipe specifies multiple authors, they will be joined into a single string (e.g. “Author One, Author Two”)

description: Option<String>

The description of the recipe.

ingredients: Vec<Ingredient>

A list of ingredients used by the recipe.

how_to_sections: Vec<HowToSection>

A list of how-to-sections for the recipe.

If the recipe does not use how-to-sections this will contain a single section without a name.

Implementations

Source

impl Recipe

pub fn to_markdown(&self) -> MarkdownBuilder<'_>

Constructs a MarkdownBuilder to convert this recipe to markdown format

Examples found in repository?
examples/markdown.rs (line 6)
2fn main() {
3    let html = std::fs::read_to_string("examples/recipe.html").unwrap();
4    let recipe = reget::parse_recipe(&html).unwrap();
5    let md = recipe
6        .to_markdown()
7        .with_url("https://example.org/recipe")
8        .with_ingredient_section("Zutaten")
9        .with_default_section("Zubereitung")
10        .convert();
11    println!("{md}");
12}